==> isis-fish-4.1.0.2-sources.jar: fr/ifremer/isisfish/util/ssh/InvalidPassphraseException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: InvalidPassphraseException.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, Code Lutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util.ssh;

/**
 * Exception throws for password input cancellation.
 *
 * @author chatellier
 * @version $Revision: 3124 $
 * 
 * Last update : $Date: 2010-11-29 19:14:09 +0100 (Mon, 29 Nov 2010) $
 * By : $Author: chatellier $
 */
public class InvalidPassphraseException extends Exception {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = -8878596298083203705L;

    /**
     * Constructor with message and cause.
     * 
     * @param message message
     * @param cause cause
     */
    public InvalidPassphraseException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructor with message.
     * 
     * @param message message
     */
    public InvalidPassphraseException(String message) {
        super(message);
    }
}

==> isis-fish-4.3.0.2-20140616.104318-1-sources.jar: fr/ifremer/isisfish/util/ssh/InvalidPassphraseException.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: InvalidPassphraseException.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 Ifremer, Code Lutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.util.ssh;

/**
 * Exception throws for password input cancellation.
 *
 * @author chatellier
 * @version $Revision: 3798 $
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (mar. 30 oct. 2012) $
 * By : $Author: echatellier $
 */
public class InvalidPassphraseException extends Exception {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = -8878596298083203705L;

    /**
     * Constructor with message and cause.
     * 
     * @param message message
     * @param cause cause
     */
    public InvalidPassphraseException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Constructor with message.
     * 
     * @param message message
     */
    public InvalidPassphraseException(String message) {
        super(message);
    }
}
